@@ -368,13 +368,7 @@ pair<bool,long> ADFSSessionInitiator::run(SPRequest& request, string& entityID,
         recoverRelayState(app, request, request, target, false);
         app.limitRedirect(request, target.c_str());
 
-        // Default is to allow externally supplied settings.
-        pair<bool,bool> externalInput = getBool("externalInput");
-        unsigned int settingMask = HANDLER_PROPERTY_MAP | HANDLER_PROPERTY_FIXED;
-        if (!externalInput.first || externalInput.second)
-            settingMask |= HANDLER_PROPERTY_REQUEST;
-
-        acClass = getString("authnContextClassRef", request, settingMask);
+        acClass = getString("authnContextClassRef", request);
     }
     else {
         // Check for a hardwired target value in the map or handler.
@@ -547,15 +541,8 @@ pair<bool,long> ADFSSessionInitiator::doRequest(
     auto_ptr_char dest(ep->getLocation());
     const URLEncoder* urlenc = XMLToolingConfig::getConfig().getURLEncoder();
 
-    const PropertySet* relyingParty = app.getRelyingParty(entity.first);
-
     string req=string(dest.get()) + (strchr(dest.get(),'?') ? '&' : '?') + "wa=wsignin1.0&wreply=" + urlenc->encode(acsLocation) +
-        "&wct=" + urlenc->encode(timebuf) + "&wtrealm=" + urlenc->encode(relyingParty->getString("entityID").second);
-    if (!authnContextClassRef) {
-        pair<bool,const char*> rpClass = relyingParty->getString("authnContextClassRef");
-        if (rpClass.first)
-            authnContextClassRef = rpClass.second;
-    }
+        "&wct=" + urlenc->encode(timebuf) + "&wtrealm=" + urlenc->encode(app.getString("entityID").second);
     if (authnContextClassRef)
         req += "&wauth=" + urlenc->encode(authnContextClassRef);
     if (!relayState.empty())
@@ -1043,7 +1030,7 @@ pair<bool,long> ADFSLogout::run(SPRequest& request, bool isHandler) const
         if (!strcmp(param, "wsignin1.0"))
             return m_login.run(request, isHandler);
         else if (strcmp(param, "wsignout1.0") && strcmp(param, "wsignoutcleanup1.0"))
-            throw FatalProfileException("Unsupported WS-Federation action parameter ($1).", params(1, param));
+            throw FatalProfileException("Unsupported WS-Federation action paremeter ($1).", params(1, param));
     }
     else if (strcmp(request.getMethod(),"GET") || !request.getParameter("notifying"))
         throw FatalProfileException("Unsupported request to ADFS protocol endpoint.");
